@@ -1,6 +1,6 @@
 package Bundle::KohaSupport;
 
-our $VERSION = '0.06';
+our $VERSION = '0.07';
 
 __END__
 
@@ -36,6 +36,8 @@ MARC::Record
 
 Set::Scalar
 
+Mail::Sendmail
+
 =head1 DESCRIPTION
 
 This bundle gathers together all installs all of the prerequisite 
@@ -74,6 +76,9 @@ Module for handling MARC records as objects
 =item Set::Scalar
 Basic Set operations.
 
+=item Mail::Sendmail
+Simple platform independant mailler.
+
 =head1 AUTHOR
 
 Mike Mylonas, <koha@dragon-is.co.nz>
